@@ -128,8 +128,6 @@ class MobyleJob:
             else:
                 self.userEmail = None
             email_notify = email_notify.lower()
-            if not self.userEmail and email_notify != 'false':
-                raise MobyleError( "email adress must be specified when email_notify is set to %s" % email_notify )
             try:
                 checkHost()
             except UserValueError ,err:
